@@ -622,6 +622,18 @@ copy_event_properties (GArray *src)
   return dst;
 }
 
+/**
+ * atspi_event_listener_register_from_callback_full:
+ * @callback: (scope async): an #AtspiEventListenerCB function pointer.
+ * @user_data: (closure callback)
+ * @callback_destroyed: (destroy callback)
+ * @event_type:
+ * @properties: (element-type utf8)
+ * @error:
+ *
+ * Returns: #TRUE if successful, otherwise #FALSE.
+ *
+ **/
 gboolean
 atspi_event_listener_register_from_callback_full (AtspiEventListenerCB callback,
 				                  void *user_data,
@@ -1006,6 +1018,9 @@ _atspi_dbus_handle_event (DBusConnection *bus, DBusMessage *message, void *data)
   if (e.source == NULL)
   {
     g_warning ("Got no valid source accessible for signal for signal %s from interface %s\n", member, category);
+    g_free (converted_type);
+    g_free (name);
+    g_free (detail);
     return DBUS_HANDLER_RESULT_HANDLED;
   }
 
