@@ -244,7 +244,7 @@ unix_read_all_fd_to_string (int      fd,
 {
   ssize_t bytes_read;
 
-  while (max_bytes > 1 && (bytes_read = read (fd, buf, MAX (4096, max_bytes - 1))))
+  while (max_bytes > 1 && (bytes_read = read (fd, buf, MIN (4096, max_bytes - 1))))
     {
       if (bytes_read < 0)
         return FALSE;
@@ -437,6 +437,9 @@ handle_a11y_enabled_change (A11yBusLauncher *app, gboolean enabled,
                                                 &builder,
                                                 &invalidated_builder),
                                  NULL);
+
+  g_variant_builder_clear (&builder);
+  g_variant_builder_clear (&invalidated_builder);
 }
 
 static void
@@ -475,6 +478,9 @@ handle_screen_reader_enabled_change (A11yBusLauncher *app, gboolean enabled,
                                                 &builder,
                                                 &invalidated_builder),
                                  NULL);
+
+  g_variant_builder_clear (&builder);
+  g_variant_builder_clear (&invalidated_builder);
 }
 
 static gboolean
