@@ -170,6 +170,10 @@ void spi_dec_dbus_emit(SpiDEController *controller, const char *interface, const
 #ifdef HAVE_X11
 void spi_dec_setup_x11 (SpiDEControllerClass *klass);
 #endif
+
+long ucs2keysym (long ucs);
+long keysym2ucs(long keysym);
+
 G_END_DECLS
 
 #endif /* DEVICEEVENTCONTROLLER_H_ */
